@@ -8,17 +8,16 @@ import sys
 REDIS_HOST = 'localhost'
 REDIS_PORT = 6379
 
-@defer.inlineCallbacks
+
 def getRedisSubscriber():
     clientCreator = protocol.ClientCreator(reactor, RedisSubscriber)
-    redis = yield clientCreator.connectTCP(REDIS_HOST, REDIS_PORT)
-    defer.returnValue(redis)
+    return clientCreator.connectTCP(REDIS_HOST, REDIS_PORT)
+
 
-@defer.inlineCallbacks
 def getRedis():
     clientCreator = protocol.ClientCreator(reactor, Redis)
-    redis = yield clientCreator.connectTCP(REDIS_HOST, REDIS_PORT)
-    defer.returnValue(redis)
+    return clientCreator.connectTCP(REDIS_HOST, REDIS_PORT)
+
 
 @defer.inlineCallbacks
 def runTest():
@@ -42,4 +41,3 @@ def main():
 
 if __name__ == "__main__":
     main()
-
